Tk::SlideShow::Sprite->Get('i7')->place(626,475);
Tk::SlideShow::Sprite->Get('i8')->place(701,555);
Tk::SlideShow::Sprite->Get('i9')->place(791,638);
Tk::SlideShow::Sprite->Get('i0')->place(896,36);
Tk::SlideShow::Sprite->Get('i10')->place(897,715);
Tk::SlideShow::Sprite->Get('i1')->place(770,104);
Tk::SlideShow::Sprite->Get('i2')->place(551,174);
Tk::SlideShow::Sprite->Get('i3')->place(348,236);
Tk::SlideShow::Sprite->Get('i4')->place(319,322);
Tk::SlideShow::Sprite->Get('i5')->place(367,387);
Tk::SlideShow::Sprite->Get('i6')->place(529,430);
Tk::SlideShow::Org->Get('i8-i9')->ftpos(5,1);
Tk::SlideShow::Org->Get('i0-i1')->ftpos(5,1);
Tk::SlideShow::Org->Get('i1-i2')->ftpos(5,1);
Tk::SlideShow::Org->Get('i2-i3')->ftpos(6,1);
Tk::SlideShow::Org->Get('i3-i4')->ftpos(5,1);
Tk::SlideShow::Org->Get('i4-i5')->ftpos(5,1);
Tk::SlideShow::Org->Get('i9-i10')->ftpos(5,1);
Tk::SlideShow::Org->Get('i5-i6')->ftpos(5,1);
Tk::SlideShow::Org->Get('i6-i7')->ftpos(5,1);
Tk::SlideShow::Org->Get('i7-i8')->ftpos(5,1);
