Tk::SlideShow::Sprite->Get('m3')->place(295,170);
Tk::SlideShow::Sprite->Get('m4')->place(245,300);
Tk::SlideShow::Sprite->Get('m5')->place(217,457);
Tk::SlideShow::Sprite->Get('m')->place(340,650);
Tk::SlideShow::Sprite->Get('m2')->place(342,66);
