Tk::SlideShow::Sprite->Get('gus10')->place(950,830);
Tk::SlideShow::Sprite->Get('gus1')->place(1214,835);
Tk::SlideShow::Sprite->Get('gus2')->place(1142,835);
Tk::SlideShow::Sprite->Get('gus3')->place(1077,834);
Tk::SlideShow::Sprite->Get('gus4')->place(1011,831);
Tk::SlideShow::Sprite->Get('image')->place(206,307);
Tk::SlideShow::Sprite->Get('gus5')->place(645,854);
Tk::SlideShow::Sprite->Get('gus6')->place(706,850);
Tk::SlideShow::Sprite->Get('anim')->place(406,293);
Tk::SlideShow::Sprite->Get('text')->place(290,148);
Tk::SlideShow::Sprite->Get('gus7')->place(764,844);
Tk::SlideShow::Sprite->Get('gus8')->place(823,840);
Tk::SlideShow::Sprite->Get('gus9')->place(887,837);
Tk::SlideShow::Sprite->Get('i2')->place(466,617);
