Tk::SlideShow::Sprite->Get('t4')->place(516,578);
Tk::SlideShow::Sprite->Get('t0')->place(512,384);
Tk::SlideShow::Sprite->Get('t1')->place(512,384);
Tk::SlideShow::Sprite->Get('t2')->place(512,384);
Tk::SlideShow::Sprite->Get('t3')->place(497,501);
