Tk::SlideShow::Sprite->Get('tfixed')->place(676,347);
Tk::SlideShow::Sprite->Get('tfangsong ti')->place(724,297);
Tk::SlideShow::Sprite->Get('tlucidatypewriter')->place(235,411);
Tk::SlideShow::Sprite->Get('tutopia')->place(112,227);
Tk::SlideShow::Sprite->Get('tlucidabright')->place(180,633);
Tk::SlideShow::Sprite->Get('tlucida')->place(676,94);
Tk::SlideShow::Sprite->Get('tsong ti')->place(133,531);
Tk::SlideShow::Sprite->Get('thelvetica')->place(719,173);
Tk::SlideShow::Sprite->Get('tsymbol')->place(146,479);
Tk::SlideShow::Sprite->Get('tcourier')->place(649,440);
Tk::SlideShow::Sprite->Get('tterminal')->place(149,340);
Tk::SlideShow::Sprite->Get('tgothic')->place(693,238);
Tk::SlideShow::Sprite->Get('tmincho')->place(145,572);
Tk::SlideShow::Sprite->Get('ttimes')->place(120,290);
Tk::SlideShow::Sprite->Get('tclean')->place(685,520);
Tk::SlideShow::Sprite->Get('tnil')->place(645,665);
Tk::SlideShow::Sprite->Get('topen look cursor')->place(238,118);
Tk::SlideShow::Sprite->Get('tnew century schoolbook')->place(322,175);
Tk::SlideShow::Sprite->Get('tcharter')->place(721,584);
Tk::SlideShow::Sprite->Get('topen look glyph')->place(229,63);
