Tk::SlideShow::Sprite->Get('ff0_5')->place(747,328);
Tk::SlideShow::Sprite->Get('advert')->place(586,431);
Tk::SlideShow::Sprite->Get('warning')->place(577,596);
Tk::SlideShow::Sprite->Get('f1')->place(116,525);
Tk::SlideShow::Sprite->Get('f2')->place(145,424);
Tk::SlideShow::Sprite->Get('f3')->place(173,345);
Tk::SlideShow::Sprite->Get('f0_5')->place(120,560);
Tk::SlideShow::Sprite->Get('f4')->place(206,239);
Tk::SlideShow::Sprite->Get('f1_5')->place(149,480);
Tk::SlideShow::Sprite->Get('f5')->place(226,128);
Tk::SlideShow::Sprite->Get('ff1')->place(741,286);
Tk::SlideShow::Sprite->Get('ff2')->place(760,238);
Tk::SlideShow::Sprite->Get('ff3')->place(804,171);
