Tk::SlideShow::Sprite->Get('a0')->place(479,333);
Tk::SlideShow::Sprite->Get('a1')->place(450,454);
Tk::SlideShow::Sprite->Get('title')->place(209,55);
Tk::SlideShow::Sprite->Get('a2')->place(447,580);
Tk::SlideShow::Sprite->Get('ex')->place(533,517);
Tk::SlideShow::Sprite->Get('ti')->place(890,90);
