Tk::SlideShow::Sprite->Get('tdobkinscript')->place(514,511);
Tk::SlideShow::Sprite->Get('gus1')->place(512,384);
Tk::SlideShow::Sprite->Get('tcoronetscript')->place(532,333);
Tk::SlideShow::Sprite->Get('tparkavenue')->place(174,631);
Tk::SlideShow::Sprite->Get('troostheavy')->place(169,383);
Tk::SlideShow::Sprite->Get('ttekton')->place(116,547);
Tk::SlideShow::Sprite->Get('tgoudyoldstyle')->place(538,81);
Tk::SlideShow::Sprite->Get('tspookyplain')->place(173,209);
Tk::SlideShow::Sprite->Get('tshalomscript')->place(182,249);
Tk::SlideShow::Sprite->Get('tzaleskicaps')->place(158,85);
Tk::SlideShow::Sprite->Get('tengraver')->place(794,513);
Tk::SlideShow::Sprite->Get('tbrushstroke')->place(847,186);
Tk::SlideShow::Sprite->Get('tgoodcitymodern(seq)')->place(281,323);
Tk::SlideShow::Sprite->Get('tcheq')->place(812,109);
Tk::SlideShow::Sprite->Get('tshalomstick')->place(177,282);
Tk::SlideShow::Sprite->Get('tagate')->place(784,469);
Tk::SlideShow::Sprite->Get('tcuneifontlight')->place(529,587);
Tk::SlideShow::Sprite->Get('tslogan')->place(117,575);
Tk::SlideShow::Sprite->Get('tflorencelight')->place(524,301);
Tk::SlideShow::Sprite->Get('tblippo')->place(791,293);
Tk::SlideShow::Sprite->Get('tcarrickcaps')->place(497,549);
Tk::SlideShow::Sprite->Get('toldtown')->place(136,661);
Tk::SlideShow::Sprite->Get('tcooper')->place(455,361);
Tk::SlideShow::Sprite->Get('tgoodcitymodern(kbd)')->place(629,115);
Tk::SlideShow::Sprite->Get('tdragonwick')->place(510,473);
Tk::SlideShow::Sprite->Get('tdavysbigkeycaps')->place(228,703);
Tk::SlideShow::Sprite->Get('teras')->place(418,416);
Tk::SlideShow::Sprite->Get('tbecker')->place(788,333);
Tk::SlideShow::Sprite->Get('tfrizquadrata')->place(521,264);
Tk::SlideShow::Sprite->Get('trudelsberg')->place(168,482);
Tk::SlideShow::Sprite->Get('tcapri')->place(771,144);
Tk::SlideShow::Sprite->Get('tfutura_poster')->place(537,225);
Tk::SlideShow::Sprite->Get('tshalomoldstyle')->place(214,354);
Tk::SlideShow::Sprite->Get('tbaskerville')->place(828,366);
Tk::SlideShow::Sprite->Get('tcracklingfire')->place(517,659);
Tk::SlideShow::Sprite->Get('telizabethann')->place(518,443);
Tk::SlideShow::Sprite->Get('tclassicheavylight')->place(563,391);
Tk::SlideShow::Sprite->Get('tvictoriassecret')->place(198,144);
Tk::SlideShow::Sprite->Get('ttribeca')->place(120,450);
Tk::SlideShow::Sprite->Get('tbodoni')->place(797,254);
Tk::SlideShow::Sprite->Get('tbraille')->place(788,220);
Tk::SlideShow::Sprite->Get('ttempofont')->place(160,177);
Tk::SlideShow::Sprite->Get('tcrillee')->place(444,624);
Tk::SlideShow::Sprite->Get('tcaligula')->place(816,81);
Tk::SlideShow::Sprite->Get('tshohlfold')->place(149,417);
Tk::SlideShow::Sprite->Get('twindsordemi')->place(180,113);
Tk::SlideShow::Sprite->Get('tannstone')->place(820,438);
Tk::SlideShow::Sprite->Get('trechtmanscript')->place(216,519);
Tk::SlideShow::Sprite->Get('tarnoldboecklin')->place(885,398);
Tk::SlideShow::Sprite->Get('tgaramond')->place(498,183);
Tk::SlideShow::Sprite->Get('tgenoa')->place(448,148);
Tk::SlideShow::Sprite->Get('tsalter')->place(111,605);
