Tk::SlideShow::Sprite->Get('titre')->place(194,59);
Tk::SlideShow::Sprite->Get('i0')->place(472,158);
Tk::SlideShow::Sprite->Get('i1')->place(566,248);
Tk::SlideShow::Sprite->Get('i2')->place(467,344);
Tk::SlideShow::Sprite->Get('i3')->place(500,441);
Tk::SlideShow::Sprite->Get('i4')->place(474,538);
Tk::SlideShow::Sprite->Get('i5')->place(448,629);
