Tk::SlideShow::Sprite->Get('test')->place(334,437)->fontFamily('charter');
Tk::SlideShow::Sprite->Get('another')->place(386,147)->fontFamily('utopia')->color('black');
Tk::SlideShow::Sprite->Get('title')->place(332,299)->fontFamily('charter')->color('red');
