Tk::SlideShow::Sprite->Get('tfixed')->place(63,345);
Tk::SlideShow::Sprite->Get('tfangsong ti')->place(233,461);
Tk::SlideShow::Sprite->Get('t0')->place(412,147);
Tk::SlideShow::Sprite->Get('tclean')->place(259,531);
Tk::SlideShow::Sprite->Get('tcourier')->place(221,440);
Tk::SlideShow::Sprite->Get('tcharter')->place(167,246);
