Tk::SlideShow::Sprite->Get('tblackforest')->place(297,364);
Tk::SlideShow::Sprite->Get('tupperwestside')->place(410,96);
Tk::SlideShow::Sprite->Get('tcomicscartoon')->place(383,634);
Tk::SlideShow::Sprite->Get('tdavysotherdingbats')->place(484,240);
Tk::SlideShow::Sprite->Get('talfreddrake')->place(298,489);
Tk::SlideShow::Sprite->Get('tduncan')->place(650,433);
Tk::SlideShow::Sprite->Get('tcartwright')->place(264,538);
Tk::SlideShow::Sprite->Get('tromeo')->place(178,433);
Tk::SlideShow::Sprite->Get('taneirin')->place(705,376);
Tk::SlideShow::Sprite->Get('tbodidly')->place(739,320);
Tk::SlideShow::Sprite->Get('tburgundian')->place(310,580);
Tk::SlideShow::Sprite->Get('tdavysdingbats')->place(363,684);
Tk::SlideShow::Sprite->Get('tgreencaps')->place(319,307);
Tk::SlideShow::Sprite->Get('tsumdumgoi')->place(359,170);
Tk::SlideShow::Sprite->Get('tsharktooth')->place(444,727);
Tk::SlideShow::Sprite->Get('tapollo')->place(727,542);
Tk::SlideShow::Sprite->Get('twesternslant')->place(378,35);
