Tk::SlideShow::Sprite->Get('i0')->place(401,173);
Tk::SlideShow::Sprite->Get('i1')->place(457,254);
Tk::SlideShow::Sprite->Get('title')->place(214,60);
Tk::SlideShow::Sprite->Get('i2')->place(406,326);
Tk::SlideShow::Sprite->Get('i3')->place(417,403);
Tk::SlideShow::Sprite->Get('i4')->place(371,486);
Tk::SlideShow::Sprite->Get('i5')->place(395,562);
