Tk::SlideShow::Sprite->Get('i7')->place(742,317);
Tk::SlideShow::Sprite->Get('i8')->place(641,178);
Tk::SlideShow::Sprite->Get('i9')->place(485,149);
Tk::SlideShow::Sprite->Get('i0')->place(283,50);
Tk::SlideShow::Sprite->Get('i10')->place(360,180);
Tk::SlideShow::Sprite->Get('i1')->place(116,164);
Tk::SlideShow::Sprite->Get('i2')->place(159,323);
Tk::SlideShow::Sprite->Get('i3')->place(220,434);
Tk::SlideShow::Sprite->Get('i4')->place(318,512);
Tk::SlideShow::Sprite->Get('i5')->place(499,552);
Tk::SlideShow::Sprite->Get('i6')->place(650,473);
Tk::SlideShow::Arrow->Get('i8-i9')->ftpos(0,3)->width(1)->shape(8,10,3);
Tk::SlideShow::Arrow->Get('i0-i1')->ftpos(6,2)->width(1)->shape(8,10,3);
Tk::SlideShow::Arrow->Get('i1-i2')->ftpos(5,1)->width(1)->shape(8,10,3);
Tk::SlideShow::Arrow->Get('i2-i3')->ftpos(5,1)->width(1)->shape(8,10,3);
Tk::SlideShow::Arrow->Get('i3-i4')->ftpos(4,1)->width(1)->shape(8,10,3);
Tk::SlideShow::Arrow->Get('i4-i5')->ftpos(4,7)->width(1)->shape(8,10,3);
Tk::SlideShow::Arrow->Get('i9-i10')->ftpos(7,2)->width(1)->shape(8,10,3);
Tk::SlideShow::Arrow->Get('i5-i6')->ftpos(2,7)->width(1)->shape(8,10,3);
Tk::SlideShow::Arrow->Get('i6-i7')->ftpos(1,5)->width(1)->shape(8,10,3);
Tk::SlideShow::Arrow->Get('i7-i8')->ftpos(1,5)->width(1)->shape(8,10,3);
