Tk::SlideShow::Sprite->Get('i7')->place(344,558);
Tk::SlideShow::Sprite->Get('i8')->place(216,434);
Tk::SlideShow::Sprite->Get('i9')->place(205,281);
Tk::SlideShow::Sprite->Get('i0')->place(572,373);
Tk::SlideShow::Sprite->Get('i10')->place(614,143);
Tk::SlideShow::Sprite->Get('i1')->place(474,459);
Tk::SlideShow::Sprite->Get('i2')->place(333,368);
Tk::SlideShow::Sprite->Get('i3')->place(527,265);
Tk::SlideShow::Sprite->Get('i4')->place(825,291);
Tk::SlideShow::Sprite->Get('i5')->place(752,437);
Tk::SlideShow::Sprite->Get('i6')->place(530,548);
Tk::SlideShow::Link->Get('i8-i9')->ftpos(1,5);
Tk::SlideShow::Link->Get('i0-i1')->ftpos(5,2);
Tk::SlideShow::Link->Get('i1-i2')->ftpos(0,5);
Tk::SlideShow::Link->Get('i2-i3')->ftpos(1,7);
Tk::SlideShow::Link->Get('i3-i4')->ftpos(3,0);
Tk::SlideShow::Link->Get('i4-i5')->ftpos(5,1);
Tk::SlideShow::Link->Get('i9-i10')->ftpos(1,7);
Tk::SlideShow::Link->Get('i5-i6')->ftpos(5,3);
Tk::SlideShow::Link->Get('i6-i7')->ftpos(7,3);
Tk::SlideShow::Link->Get('i7-i8')->ftpos(0,5);
